# Base makefile for a test suite.
#
# Implements a target 'test_cases' which is built by the master unit
# test suite.
#

# Copyright 2015 Andrew Dawson, Peter Dueben
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Include the base pFUnit makefile.
include $(PFUNIT)/include/base.mk

# Phony declaration for the required target.
.PHONY: test_cases clean-fsources

# Sources are all .pf test suite definition files, and objects are the
# compiled test modules.
DEFS := $(wildcard *.pf)
SRCS := $(DEFS:.pf=.F90)
OBJS := $(DEFS:.pf=$(OBJ_EXT))

# The tests need the module file for the emulator.
RPEMOD = "../../../modules"

# The required target builds all test object files.
test_cases: $(SRCS) $(OBJS)

# Fortran 90 files are generated from the definition files by the program
# pFUnitParser.py, part of pFUnit. The generated files may include C
# preprocessor directives so have the .F90 extension.
%.F90: %.pf
	$(PFUNIT)/bin/pFUnitParser.py $< $@

# Objects are generated from Fortran 90 source via the Fortran compiler.
%$(OBJ_EXT): %.F90
	$(F90) -I../common -I$(PFUNIT)/mod -I$(RPEMOD) -c $(FFLAGS) $(FPPFLAGS) $<

# Over-ride the inherited clean rule so that it also cleans Fortran source
# files (which are machine generated by pFUnitParser.py).
clean: local-base0-clean clean-fsources

# Remove generated Fortran sources.
clean-fsources:
	$(RM) $(SRCS)
